==> mx-packageinstaller-pkglist_21.08.5mx21.tar.xz: all/keepassx.pm <==
<?xml version="1.0"?>
<app>

<category>
Misc
</category>

<name>
KeepassX
</name>

<description>
   <am>KeePassX is a free/open-source password manager/safe</am>
   <ar>KeePassX is a free/open-source password manager/safe</ar>
   <bg>KeePassX is a free/open-source password manager/safe</bg>
   <bn>KeePassX is a free/open-source password manager/safe</bn>
   <ca>KeePassX és un gestor de contrasenyes lliure/codi obert</ca>
   <cs>KeePassX is a free/open-source password manager/safe</cs>
   <da>KeePassX er en fri/open source adgangskodehåndtering/-skab</da>
   <de>KeePassX ist ein kostenloser/open-source Passwortmanager/-safe</de>
   <el>Το KeePassX είναι ένας διαχειριστής κωδικών πρόσβασης ελεύθερου/ανοιχτού κώδικα</el>
   <en>KeePassX is a free/open-source password manager/safe</en>
   <es>Administrador de contraseñas de código abierto</es>
   <et>KeePassX is a free/open-source password manager/safe</et>
   <eu>KeePassX is a free/open-source password manager/safe</eu>
   <fa>KeePassX is a free/open-source password manager/safe</fa>
   <fil_PH>KeePassX is a free/open-source password manager/safe</fil_PH>
   <fi>KeePassX is a free/open-source password manager/safe</fi>
   <fr>KeePassX est un gestionnaire sécurisé open-source de mots de passe</fr>
   <he_IL>KeePassX is a free/open-source password manager/safe</he_IL>
   <hi>KeePassX is a free/open-source password manager/safe</hi>
   <hr>KeePassX is a free/open-source password manager/safe</hr>
   <hu>KeePassX is a free/open-source password manager/safe</hu>
   <id>KeePassX is a free/open-source password manager/safe</id>
   <is>KeePassX is a free/open-source password manager/safe</is>
   <it>KeePassX è un gestore di password free/open-source</it>
   <ja_JP>KeePassX is a free/open-source password manager/safe</ja_JP>
   <ja>KeePassX is a free/open-source password manager/safe</ja>
   <kk>KeePassX is a free/open-source password manager/safe</kk>
   <ko>KeePassX is a free/open-source password manager/safe</ko>
   <lt>KeePassX is a free/open-source password manager/safe</lt>
   <mk>KeePassX is a free/open-source password manager/safe</mk>
   <mr>KeePassX is a free/open-source password manager/safe</mr>
   <nb>KeePassX is a free/open-source password manager/safe</nb>
   <nl>KeePassX is een gratis/open-source wachtwoord manager/kluis</nl>
   <pl>KeePassX to bezpłatny menedżer haseł/sejf o otwartym kodzie źródłowym</pl>
   <pt_BR>Guarda e gestão de senhas (palavras-passe) em software livre e de fonte aberta</pt_BR>
   <pt>Guarda e gestão de senhas (palavras-passe) em software livre e de fonte aberta</pt>
   <ro>KeePassX is a free/open-source password manager/safe</ro>
   <ru>KeePassX - менеджер паролей с открытым кодом (форк KeePass)</ru>
   <sk>KeePassX is a free/open-source password manager/safe</sk>
   <sl>KeePassXje brezplačen odprtokodni urejevalnik/sef za gesla</sl>
   <sq>KeePassX is a free/open-source password manager/safe</sq>
   <sr>KeePassX is a free/open-source password manager/safe</sr>
   <sv>KeePassX är en fri/öppen källkod lösenordshanterare/förvarare</sv>
   <tr>KeePassX is a free/open-source password manager/safe</tr>
   <uk>KeePassX вільний та відкритий менеджер і сховище паролів</uk>
   <vi>KeePassX is a free/open-source password manager/safe</vi>
   <zh_CN>KeePassX is a free/open-source password manager/safe</zh_CN>
   <zh_TW>KeePassX is a free/open-source password manager/safe</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>https://screenshots.debian.net/screenshots/000/015/308/large.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
keepassx
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
keepassx
</uninstall_package_names>
</app>

==> mx-packageinstaller-pkglist_21.11.01mx21.tar.xz: all/keepassx.pm <==
<?xml version="1.0"?>
<app>

<category>
Misc
</category>

<name>
KeepassX
</name>

<description>
   <am>KeePassX is a free/open-source password manager/safe</am>
   <ar>KeePassX is a free/open-source password manager/safe</ar>
   <bg>KeePassX is a free/open-source password manager/safe</bg>
   <bn>KeePassX is a free/open-source password manager/safe</bn>
   <ca>KeePassX és un gestor de contrasenyes lliure/codi obert</ca>
   <cs>KeePassX is a free/open-source password manager/safe</cs>
   <da>KeePassX er en fri/open source adgangskodehåndtering/-skab</da>
   <de>KeePassX ist ein kostenloser/open-source Passwortmanager/-safe</de>
   <el>Το KeePassX είναι ένας διαχειριστής κωδικών πρόσβασης ελεύθερου/ανοιχτού κώδικα</el>
   <en>KeePassX is a free/open-source password manager/safe</en>
   <es>Administrador de contraseñas de código abierto</es>
   <et>KeePassX is a free/open-source password manager/safe</et>
   <eu>KeePassX is a free/open-source password manager/safe</eu>
   <fa>KeePassX is a free/open-source password manager/safe</fa>
   <fil_PH>KeePassX is a free/open-source password manager/safe</fil_PH>
   <fi>KeePassX is a free/open-source password manager/safe</fi>
   <fr>KeePassX est un gestionnaire sécurisé open-source de mots de passe</fr>
   <he_IL>KeePassX is a free/open-source password manager/safe</he_IL>
   <hi>KeePassX is a free/open-source password manager/safe</hi>
   <hr>KeePassX is a free/open-source password manager/safe</hr>
   <hu>KeePassX is a free/open-source password manager/safe</hu>
   <id>KeePassX is a free/open-source password manager/safe</id>
   <is>KeePassX is a free/open-source password manager/safe</is>
   <it>KeePassX è un gestore di password free/open-source</it>
   <ja_JP>KeePassX is a free/open-source password manager/safe</ja_JP>
   <ja>KeePassX is a free/open-source password manager/safe</ja>
   <kk>KeePassX is a free/open-source password manager/safe</kk>
   <ko>KeePassX is a free/open-source password manager/safe</ko>
   <lt>KeePassX is a free/open-source password manager/safe</lt>
   <mk>KeePassX is a free/open-source password manager/safe</mk>
   <mr>KeePassX is a free/open-source password manager/safe</mr>
   <nb>KeePassX is a free/open-source password manager/safe</nb>
   <nl>KeePassX is een gratis/open-source wachtwoord manager/kluis</nl>
   <pl>KeePassX to bezpłatny menedżer haseł/sejf o otwartym kodzie źródłowym</pl>
   <pt_BR>Guarda e gestão de senhas (palavras-passe) em software livre e de fonte aberta</pt_BR>
   <pt>Guarda e gestão de senhas (palavras-passe) em software livre e de fonte aberta</pt>
   <ro>KeePassX is a free/open-source password manager/safe</ro>
   <ru>KeePassX - менеджер паролей с открытым кодом (форк KeePass)</ru>
   <sk>KeePassX is a free/open-source password manager/safe</sk>
   <sl>KeePassXje brezplačen odprtokodni urejevalnik/sef za gesla</sl>
   <sq>KeePassX is a free/open-source password manager/safe</sq>
   <sr>KeePassX is a free/open-source password manager/safe</sr>
   <sv>KeePassX är en fri/öppen källkod lösenordshanterare/förvarare</sv>
   <tr>KeePassX is a free/open-source password manager/safe</tr>
   <uk>KeePassX вільний та відкритий менеджер і сховище паролів</uk>
   <vi>KeePassX is a free/open-source password manager/safe</vi>
   <zh_CN>KeePassX is a free/open-source password manager/safe</zh_CN>
   <zh_TW>KeePassX is a free/open-source password manager/safe</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>https://screenshots.debian.net/shrine/screenshot/15308/simage/large-fa1c9a17fe53dd738f36b802f1986bdc.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
keepassx
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
keepassx
</uninstall_package_names>
</app>
